"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processor = void 0;
const gatsby_source_filesystem_1 = require("gatsby-source-filesystem");
const metadataProcessor_1 = require("./metadataProcessor");
const tableOfContent_1 = require("./tableOfContent");
const processor = async (blocks, actions, getCache, createNodeId, reporter) => {
    const { thumbnail, tableOfContents, updatedBlocks } = await processBlocksForContent(blocks, actions, getCache, createNodeId, reporter);
    await (0, metadataProcessor_1.processMetadata)(blocks, actions, createNodeId, reporter);
    return [thumbnail, tableOfContents, updatedBlocks];
};
exports.processor = processor;
const processBlocksForContent = async (blocks, actions, getCache, createNodeId, reporter) => {
    const tableOfContents = [];
    let thumbnail = null;
    const updatedBlocks = (await Promise.all(blocks.map(async (block) => {
        await (0, tableOfContent_1.processTableOfContents)(block, tableOfContents);
        if (isImageBlock(block)) {
            return await processImageBlock(block, actions, getCache, createNodeId, reporter);
        }
        return block;
    }))).filter((block) => block !== null);
    return { thumbnail, tableOfContents, updatedBlocks };
};
const isImageBlock = (block) => {
    return block.type === "image" && "image" in block;
};
const processImageBlock = async (block, actions, getCache, createNodeId, reporter) => {
    const { createNode } = actions;
    if (block.type === "image" && "image" in block) {
        const imageSourceType = block.image.type;
        const imageUrl = imageSourceType === `external`
            ? block.image.external?.url
            : block.image?.file?.url;
        if (!imageUrl)
            return null;
        try {
            const fileNode = await (0, gatsby_source_filesystem_1.createRemoteFileNode)({
                url: imageUrl,
                parentNodeId: block.id,
                getCache,
                createNode,
                createNodeId,
            });
            if (fileNode) {
                const updatedBlock = {
                    ...block,
                    image: {
                        fileId: fileNode.id,
                        caption: block.image.caption,
                    },
                };
                reporter.info(`[SUCCESS] Image processed: ${fileNode.id}`);
                return updatedBlock;
            }
        }
        catch (error) {
            reporter.warn(`[WARNING] Failed to download image: ${imageUrl}`);
        }
    }
    return null;
};
